@@ -44,6 +44,13 @@ class Context:
         """
     self.properties.headers[key] = value
 
+  def add_header(self, headers: dict):
+    """
+        Añade o actualiza una cabecera en el contexto
+        :param headers: diccionario de cabeceras
+        """
+    self.properties.headers.update(headers)
+
   def has_header(self, key: str) -> bool:
     """Indica si esta presente la cabecera en el contexto
 
@@ -85,6 +92,17 @@ class ContextFactory:
 
     return Context(properties)
 
+  @classmethod
+  def create_from_headers(cls, headers: dict) -> Context:
+    """
+        Crea una instancia del contexto a partir de las cabeceras
+        :param headers: diccionario con las cabeceras del mensaje
+        :return:
+        """
+    context = cls.create_empty()
+    context.add_headers(headers)
+    return context
+
 
 class Accelerator:
   """
